@@ -1,30 +1,57 @@
+from grafana_backup.create_org import main as create_org
+from grafana_backup.api_checks import main as api_checks
 from grafana_backup.create_folder import main as create_folder
 from grafana_backup.create_datasource import main as create_datasource
 from grafana_backup.create_dashboard import main as create_dashboard
 from grafana_backup.create_alert_channel import main as create_alert_channel
+from grafana_backup.create_user import main as create_user
+from grafana_backup.s3_download import main as s3_download
 from glob import glob
-import tarfile, tempfile
+import sys, tarfile, tempfile
 
 
 def main(args, settings):
-    archive_file = args.get('<archive_file>', None)
+    arg_archive_file = args.get('<archive_file>', None)
     arg_components = args.get('--components', False)
+    aws_s3_bucket_name = settings.get('AWS_S3_BUCKET_NAME')
 
-    try:
-        tarfile.is_tarfile(archive_file)
-    except IOError as e:
-        print(str(e))
+    (status, json_resp, api_version) = api_checks(settings)
+
+    # Do not continue if API is unavailable or token is not valid
+    if not status == 200:
+        print("server status is not ok: {0}".format(json_resp))
         sys.exit(1)
 
+    # Use tar data stream if S3 bucket name is specified
+    if aws_s3_bucket_name:
+        s3_data = s3_download(args, settings)
+        try:
+            tar = tarfile.open(fileobj=s3_data, mode='r:gz')    
+        except Exception as e:
+            print(str(e))
+            sys.exit(1)
+    else:
+        try:
+            tarfile.is_tarfile(name=arg_archive_file)
+        except IOError as e:
+            print(str(e))
+            sys.exit(1)
+        try:
+            tar = tarfile.open(name=arg_archive_file, mode='r:gz')
+        except Exception as e:
+            print(str(e))
+            sys.exit(1)
+
     with tempfile.TemporaryDirectory() as tmpdir:
-        tar = tarfile.open(archive_file, 'r')
         tar.extractall(tmpdir)
         tar.close()
 
         restore_functions = { 'folder': create_folder,
                               'datasource': create_datasource,
                               'dashboard': create_dashboard,
-                              'alert_channel': create_alert_channel }
+                              'alert_channel': create_alert_channel,
+                              'organization': create_org,
+                              'user': create_user}
 
         if arg_components:
             arg_components_list = arg_components.split(',')
